@@ -8,11 +8,15 @@ T = typing.TypeVar("T")
 
 @dataclass
 class MapBefore:
-    """Mixing for applying a function before checking equality.
+    """Mixing for applying a function before checking equality."""
 
-    Attributes:
-        map_before : the mapping function to apply
-    """
+    def __init__(self, map_before: typing.Optional[typing.Callable] = None):
+        """Mixing for applying a function before checking equality.
+
+        Args:
+            map_before : the mapping function to apply
+        """
+        self.map_before = map_before
 
     map_before: typing.Optional[typing.Callable] = None
 
@@ -28,13 +32,18 @@ class Satisfies:
     """Mixin for checking equality by using a predicate function.
 
     If `satisfies(obj)` returns `True`, then it is equal.
-
-    Attributes:
-        satisfies : object must satisfy predicate
     """
 
     satisfies: typing.Optional[typing.Callable[[typing.Any], bool]] = None
 
+    def __init__(self, satisfies: typing.Optional[typing.Callable[[typing.Any], bool]] = None):
+        """Mixin for checking equality by using a predicate function.
+
+        Args:
+            satisfies : object must satisfy predicate
+        """
+        self.satisfies = satisfies
+
     def __eq__(self, other):
         if self.satisfies:
             try:
@@ -46,14 +55,18 @@ class Satisfies:
 
 @dataclass
 class Equals(typing.Generic[T]):
-    """Mixin for checking equality using a specific object to compare against.
-
-    Attributes:
-        equals : the object to check equality with
-    """
+    """Mixin for checking equality using a specific object to compare against."""
 
     equals: typing.Optional[T] = None
 
+    def __init__(self, equals: typing.Optional[T] = None):
+        """Mixin for checking equality using a specific object to compare against.
+
+        Args:
+            equals : the object to check equality with
+        """
+        self.equals = equals
+
     def __eq__(self, other):
         if self.equals is not None:
             if not other == self.equals:
@@ -67,13 +80,18 @@ class Vars:
 
     The attributes are compared as a dict. So anything that can be compared
     with a dict can be used as `vars` argument, including other expyct objects like `expyct.Dict`.
-
-    Attributes:
-        vars : object attributes (result of `vars()`) must equal
     """
 
     vars: typing.Optional[typing.Any] = None
 
+    def __init__(self, vars: typing.Optional[typing.Any] = None):
+        """Mixin for checking the presence of specific object attributes.
+
+        Args:
+            vars : object attributes (result of `vars()`) must equal
+        """
+        self.vars = vars
+
     def __eq__(self, other):
         if self.vars is not None:
             if not vars(other) == self.vars:
@@ -83,14 +101,18 @@ class Vars:
 
 @dataclass
 class Optional:
-    """Mixin for matching with `None`.
-
-    Attributes:
-        optional : whether `None` is allowed
-    """
+    """Mixin for matching with `None`."""
 
     optional: typing.Optional[bool] = None
 
+    def __init__(self, optional: typing.Optional[bool] = None):
+        """Mixin for matching with `None`.
+
+        Args:
+            optional : whether `None` is allowed [default: `False`]
+        """
+        self.optional = optional
+
     def __eq__(self, other):
         if other is None:
             if self.optional is not None:
@@ -102,16 +124,25 @@ class Optional:
 
 @dataclass
 class Instance:
-    """Match any object that is a class instance.
-
-    Attributes:
-        type : type of object must equal to given type
-        instance_of : object must be an instance of given type
-    """
+    """Match any object that is a class instance."""
 
     type: typing.Optional[typing.Type] = None
     instance_of: typing.Optional[typing.Type] = None
 
+    def __init__(
+        self,
+        type: typing.Optional[typing.Type] = None,
+        instance_of: typing.Optional[typing.Type] = None,
+    ):
+        """Match any object that is a class instance.
+
+        Args:
+            type : type of object must equal to given type
+            instance_of : object must be an instance of given type
+        """
+        self.type = type
+        self.instance_of = instance_of
+
     def __eq__(self, other):
         # TODO check
         if (
@@ -130,16 +161,25 @@ class Instance:
 
 @dataclass
 class Type:
-    """Match any object that is a type.
-
-    Attributes:
-        superclass_of : the type of which the matched object must be a superclass
-        subclass_of : the type of which the matched object must be a subclass
-    """
+    """Match any object that is a type."""
 
     superclass_of: typing.Optional[typing.Type] = None
     subclass_of: typing.Optional[typing.Type] = None
 
+    def __init__(
+        self,
+        superclass_of: typing.Optional[typing.Type] = None,
+        subclass_of: typing.Optional[typing.Type] = None,
+    ):
+        """Match any object that is a type.
+
+        Args:
+            superclass_of : the type of which the matched object must be a superclass
+            subclass_of : the type of which the matched object must be a subclass
+        """
+        self.superclass_of = superclass_of
+        self.subclass_of = subclass_of
+
     def __eq__(self, other):
         if not (type(other) == type or type(other) == abc.ABCMeta):
             return False
