@@ -18,5 +18,13 @@ class OneOf:
 
     options: typing.Collection
 
+    def __init__(self, options: typing.Collection):
+        """Object must equal one of the given options.
+
+        Args:
+            options: objects to compare to
+        """
+        self.options = options
+
     def __eq__(self, other):
         return any(option.__eq__(other) for option in self.options)
